@@ -27,7 +27,6 @@ from .spec import SpecParser
 from .url import unquote
 
 from collections import namedtuple
-import imp
 import itertools
 import logging
 import os
@@ -338,45 +337,6 @@ class Application(object):
     def addDocRequest(self):
         self.addRequest(DocAction())
 
-    # Helper to find a path's package imp.load_module arguments (and load the package)
-    @staticmethod
-    def loadPackageByPath(pkgPath):
-
-        # If path is a module file get the package directory
-        if not os.path.isdir(pkgPath):
-            pkgPath = os.path.dirname(pkgPath)
-
-        # Break the package directory into possible module name parts
-        pkgParts = os.path.abspath(pkgPath).split(os.sep)[1:]
-
-        # Try to find the full package name part-by-part starting with the most-detailed possible package name
-        for iPartStart in xrange_(len(pkgParts)):
-            loadModules = []
-            partPath = None
-            for iPart in xrange_(iPartStart, len(pkgParts)):
-                try:
-                    partFile, partPath, partDesc = imp.find_module(pkgParts[iPart], None if partPath is None else [partPath])
-                    pkgName = '.'.join(pkgParts[iPartStart:iPart + 1])
-                    loadModules.append((pkgName, partFile, partPath, partDesc))
-
-                    # If this is a module then it can't be part of the module path - close it and move on
-                    if partFile is not None:
-                        partFile.close()
-                        break
-                    # Is this the package we're looking for?
-                    elif os.path.samefile(pkgPath, partPath):
-                        # Load all package in the package path in order
-                        for loadModuleArgs in loadModules:
-                            if loadModuleArgs[0] not in sys.modules:
-                                imp.load_module(*loadModuleArgs)
-                        # Return the load_module args for the package path
-                        return loadModules[-1]
-                except ImportError:
-                    # Import error - move on
-                    break
-
-        return None, None, None, None
-
     # Generator to recursively load all modules
     @classmethod
     def loadModules(cls, moduleDir, moduleExt = '.py'):
@@ -385,39 +345,42 @@ class Application(object):
         if not os.path.isdir(moduleDir):
             raise IOError('%r not found or is not a directory' % (moduleDir,))
 
+        # Where is this module on the system path?
+        moduleDirParts = moduleDir.split(os.sep)
+        def findModuleNameIndex():
+            for sysPath in sys.path:
+                for iModulePart in xrange_(len(moduleDirParts) - 1, 0, -1):
+                    moduleNameParts = moduleDirParts[iModulePart:]
+                    sysModulePath = os.path.join(sysPath, *moduleNameParts)
+                    if os.path.isdir(sysModulePath) and os.path.samefile(moduleDir, sysModulePath):
+                        return len(moduleDirParts) - len(moduleNameParts)
+            else:
+                raise ImportError('%r not found on system path' % (moduleDir,))
+        ixModuleName = findModuleNameIndex()
+
         # Recursively find module files
-        moduleDirNorm = os.path.abspath(os.path.normpath(moduleDir))
-        for dirpath, dirnames, filenames in os.walk(moduleDirNorm):
+        for dirpath, dirnames, filenames in os.walk(moduleDir):
 
             # Skip Python 3.x cache directories
             if os.path.basename(dirpath) == '__pycache__':
                 continue
 
-            # Search for the directory's package path
-            pkgName, pkgFile, pkgPath, pkgDesc = cls.loadPackageByPath(dirpath)
-            if pkgName is None:
-                continue
-
-            # Load each module file in the directory
+            # Load each sub-module file in the directory
+            submoduleParts = dirpath.split(os.sep)
             for filename in filenames:
-                (base, ext) = os.path.splitext(filename)
+
+                # Skip non-module files
+                (basename, ext) = os.path.splitext(filename)
                 if ext != moduleExt:
                     continue
 
                 # Skip package __init__ files
-                if base == '__init__':
+                if basename == '__init__':
                     continue
 
-                # Load the module
-                moduleName = pkgName + '.' + base
-                module = sys.modules.get(moduleName)
-                if module is None:
-                    moduleFile, modulePath, moduleDesc = imp.find_module(base, [pkgPath])
-                    try:
-                        module = imp.load_module(moduleName, moduleFile, modulePath, moduleDesc)
-                    finally:
-                        moduleFile.close()
-                yield module
+                # Load the sub-module
+                submoduleName = '.'.join(itertools.islice(submoduleParts, ixModuleName, None)) + '.' + basename
+                yield __import__(submoduleName, globals(), locals(), ['.'])
 
     # Recursively load all requests in a directory
     def loadRequests(self, moduleDir, moduleExt = '.py'):
